- x
a pvEBayes object, which is the output of the function
pvEBayes or pvEBayes_tune.
- num_top_AEs
a number of most significant AEs appearing in the plot.
Default to 10.
- num_top_drugs
a number of most significant drugs appearing in the
plot. Default to 7.
- specified_AEs
a vector of AE names that are specified to appear in the
plot. If a vector of AEs is given, argument num_top_AEs will be ignored.
- specified_drugs
a vector of drug names that are specified to appear in
the plot. If a vector of drugs is given, argument num_top_drugs will be
ignored.
- N_threshold
a integer greater than 0. Any AE-drug combination with
observation smaller than N_threshold will be filtered out.
- text_shift
numeric. Controls the relative position of text labels,
(e.g., "N = 1", "E = 2"). A larger value shifts the "E = 2" further away from
its original position.
- x_lim_scalar
numeric. An x-axis range scalar that ensures text labels
are appropriately included in the plot.
- text_size
numeric. Controls the size of text labels,
(e.g., "N = 1", "E = 2").
- log_scale
logical. If TRUE, the eye plot displays the posterior
distribution of \(\log(\lambda_{ij})\) for the selected AEs and drugs.