get_posterior_prob: Obtain posterior probability of being a signal

View source: R/pvEBayes_object_S3_methods.R

get_posterior_probR Documentation

Obtain posterior probability of being a signal

Description

Obtain posterior probability of being a signal

Usage

get_posterior_prob(obj, cutoff_signal = 1.001)

Arguments

obj

a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.

cutoff_signal

numeric. Threshold for signal detection. An AE-drug combination is classified as a detected signal if its 5th posterior percentile exceeds this threshold.

Value

a matrix

Examples


fit <- pvEBayes(
  contin_table = statin2025_44, model = "general-gamma",
  alpha = 0.3, n_posterior_draws = 1000
)

posterior_probs <- get_posterior_prob(fit,
cutoff_signal = 1.001)

pvEBayes documentation built on June 17, 2026, 1:08 a.m.