Skip to contents

Obtain posterior probability of being a signal

Usage

get_posterior_prob(obj, cutoff_signal = 1.001)

Arguments

obj

a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.

cutoff_signal

numeric. Threshold for signal detection. An AE-drug combination is classified as a detected signal if its 5th posterior percentile exceeds this threshold.

Value

a matrix