Obtain posterior probability of being a signal
Source:R/pvEBayes_object_S3_methods.R
get_posterior_prob.RdObtain posterior probability of being a signal
Arguments
- obj
a
pvEBayesobject, which is the output of the function pvEBayes or pvEBayes_tune.- cutoff_signal
numeric. Threshold for signal detection. An AE-drug combination is classified as a detected signal if its 5th posterior percentile exceeds this threshold.