powered by
This function defines the S3 logLik method for objects of class pvEBayes. It extracts the log marginal likelihood from a fitted model.
logLik
pvEBayes
# S3 method for pvEBayes logLik(object, ...)
returns log marginal likelihood of a pvEBayes object.
a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.
other input parameters. Currently unused.
fit <- pvEBayes( contin_table = statin2025_44, model = "general-gamma", alpha = 0.3, n_posterior_draws = NULL ) logLik(fit)
Run the code above in your browser using DataLab