View source: R/pvEBayes_object_S3_methods.R
| posterior_draws | R Documentation |
This function generates posterior draws from the posterior distribution of
\lambda_{ij} for each AE-drug combination, based on a fitted empirical
Bayes model. The posterior draws can be used to compute credible intervals,
visualize posterior distributions, or support downstream inference.
posterior_draws(obj, n_posterior_draws = 1000, verbose = TRUE)
obj |
a |
n_posterior_draws |
number of posterior draws for each AE-drug combination. |
verbose |
logical. If is TRUE (default), a progress bar is displayed to the console. |
The function returns an S3 object of class pvEBayes with posterior draws.
fit <- pvEBayes(
contin_table = statin2025_44, model = "general-gamma",
alpha = 0.3, n_posterior_draws = NULL
)
fit_with_draws <- posterior_draws(fit, n_posterior_draws = 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.