posterior_draws: Generate posterior draws for each AE-drug combination
Description
This function generates posterior draws from the posterior distribution of
\(\lambda_{ij}\) for each AE-drug combination, based on a fitted empirical
Bayes model. The posterior draws can be used to compute credible intervals,
visualize posterior distributions, or support downstream inference.
Usage
posterior_draws(obj, n_posterior_draws = 1000)
Value
The function returns an S3 object of class pvEBayes with posterior draws.
Arguments
obj
a pvEBayes object, which is the output of the function
pvEBayes or pvEBayes_tune.
n_posterior_draws
number of posterior draws for each AE-drug
combination.