Learn R Programming

pvEBayes (version 0.2.1)

print.pvEBayes: Print method for a pvEBayes object

Description

This function defines the S3 print method for objects of class pvEBayes. It displays a concise description of the fitted model.

Usage

# S3 method for pvEBayes
print(x, ...)

Value

Invisibly returns the input pvEBayes object.

Arguments

x

a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.

...

other input parameters. Currently unused.

Examples

Run this code

obj <- pvEBayes(
  contin_table = statin2025_44, model = "general-gamma",
  alpha = 0.5, n_posterior_draws = 10000
)

print(obj)

Run the code above in your browser using DataLab