powered by
This function defines the S3 print method for objects of class pvEBayes. It displays a concise description of the fitted model.
print
pvEBayes
# S3 method for pvEBayes print(x, ...)
Invisibly returns the input pvEBayes object.
a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.
other input parameters. Currently unused.
obj <- pvEBayes( contin_table = statin2025_44, model = "general-gamma", alpha = 0.5, n_posterior_draws = 10000 ) print(obj)
Run the code above in your browser using DataLab