summary.pvEBayes: Summary method for a pvEBayes object

View source: R/pvEBayes_object_S3_methods.R

summary.pvEBayesR Documentation

Summary method for a pvEBayes object

Description

This function defines the S3 summary method for objects of class pvEBayes. It provides a detailed summary of the fitted model.

Usage

## S3 method for class 'pvEBayes'
summary(object, return = NULL, ...)

Arguments

object

a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.

return

a character string specifying which component the summary function should return.Valid options include: "prior parameters", "likelihood", "detected signal", "posterior draws" and "posterior draws long format". If set to NULL (default), a summary table will be returned (see 'summary_table_pvEBayes()'). Note that the input for 'return' is case-sensitive.

...

other input parameters. Currently unused.

Value

If return = NULL (default), the function returns a summary table generated by summary_table_pvEBayes(), after printing the fitted pvEBayes object.

If return is specified, the function returns the requested component:

⁠prior parameters⁠

A list of estimated prior parameters.

likelihood

The fitted model log marginal likelihood.

⁠detected signal⁠

A logical matrix indicating AE-drug pairs if P(\lambda > 1.001 \mid N) > 0.95. For signal detection with specified threshold parameters, see 'get_posterior_prob()'

⁠posterior draws⁠

Posterior draws of the signal strength for each AE-drug pair in default array format.

⁠posterior draws long format⁠

Posterior draws of the signal strength for each AE-drug pair in stacked long format.

Examples


obj <- pvEBayes(
  contin_table = statin2025_44, model = "general-gamma",
  alpha = 0.5, n_posterior_draws = 10000
)

summary(obj)


pvEBayes documentation built on June 17, 2026, 1:08 a.m.