summary.pvEBayes: Summary method for a pvEBayes object
Description
This function defines the S3 summary method for objects of class
pvEBayes. It provides a detailed summary of the fitted model.
Usage
# S3 method for pvEBayes
summary(object, return = NULL, ...)
Value
a list including estimated prior parameters, log_marginal_likelihood,
indicator matrix of detected signal and posterior_draws for each AE-drug
pair.
Arguments
object
a pvEBayes object, which is the output of the function
pvEBayes or pvEBayes_tune.
return
a character string specifying which component the summary
function should return.Valid options include: "prior parameters",
"likelihood", "detected signal" and "posterior draws". If set to NULL
(default), all components will be returned in a list. Note that the input
for 'return' is case-sensitive.