summary_table_pvEBayes: Obtain a summary table for a pvEBayes object

View source: R/pvEBayes_object_S3_methods.R

summary_table_pvEBayesR Documentation

Obtain a summary table for a pvEBayes object

Description

Obtain a summary table for a pvEBayes object

Usage

summary_table_pvEBayes(x, cutoff_signal = 1.001)

Arguments

x

a pvEBayes object, which is the output of the function pvEBayes or pvEBayes_tune.

cutoff_signal

numeric. Threshold for signal detection. An AE-drug combination is classified as a detected signal if its 5th posterior percentile exceeds this threshold.

Value

a data.table that summarizes reporting count (N), expected null value (E), posterior probability of being a signal (post_prob), posterior signal strength median (q50), 5-th and 95-th posterior signal strength percentile (q05 and q95) for each AE-drug combination.

Examples


fit <- pvEBayes(
  contin_table = statin2025_44, model = "general-gamma",
  alpha = 0.5, n_posterior_draws = 100
)

summary_table_pvEBayes(fit)


pvEBayes documentation built on June 17, 2026, 1:08 a.m.